@@ -412,18 +412,21 @@ bool file_open_dialog(char **name, uint *mode)
 	mode_input->insertstring("autodetect");
 	mode_input->insertstring("binary");
 	mode_input->insertstring("text");
-
+	
+	mode_input->growmode = MK_GM(GMH_LEFT, GMV_BOTTOM);
+	
 	d->insert(mode_input);
 	
 	/* mode (text) */
-	c=b;
-	c.x=1;
-	c.y=b.h-4;
-	c.w=9;
-	c.h=1;
+	c = b;
+	c.x = 1;
+	c.y = b.h-4;
+	c.w = 9;
+	c.h = 1;
 
 	ht_label *mode_text = new ht_label();
 	mode_text->init(&c, "~mode", mode_input);
+	mode_text->growmode = MK_GM(GMH_LEFT, GMV_BOTTOM);
 
 	d->insert(mode_text);
 
@@ -651,7 +654,7 @@ const char *ht_project::get_filename()
 
 void ht_project::load(ObjectStream &s)
 {
-// FIXME: probably not The Right Thing
+	// FIXME: probably not The Right Thing
 	String fn;
 	filename = ht_strdup(s.getDesc(fn).contentChar());
 	AVLTree::load(s);
@@ -818,13 +821,14 @@ void ht_project_listbox::handlemsg(htmsg *msg)
 				char fn[FILENAME_MAX];
 				if (file_chooser("Add project item", fn, sizeof fn)) {
 					char ffn[HT_NAME_MAX];
-					char dir[HT_NAME_MAX];
-					if ((sys_common_canonicalize(ffn, fn, NULL, sys_is_path_delim) == 0)
-					&& (sys_basename(fn, ffn) == 0)
-					&& (sys_dirname(dir, ffn) == 0)) {
+					char *dir;
+					if (sys_common_canonicalize(ffn, fn, NULL, sys_is_path_delim) == 0
+					 && sys_basename(fn, ffn) == 0
+					 && (dir = sys_dirname(ffn)) ) {
 						ht_project_item *p = new ht_project_item(fn, dir);
 						((ht_project*)project)->insert(p);
 						app->sendmsg(msg_project_changed);
+						free(dir);
 					}
 				}
 			}
@@ -1279,15 +1283,15 @@ void ht_logviewer::handlemsg(htmsg *msg)
 	switch (msg->msg) {
 		case msg_get_scrollinfo:
 			switch (msg->data1.integer) {
-				case gsi_vscrollbar: {
-					gsi_scrollbar_t *p=(gsi_scrollbar_t*)msg->data2.ptr;
-					if (!get_vscrollbar_pos(&p->pstart, &p->psize)) {
-						p->pstart = 0;
-						p->psize = 100;
-					}
-					clearmsg(msg);
-					return;
+			case gsi_vscrollbar: {
+				gsi_scrollbar_t *p=(gsi_scrollbar_t*)msg->data2.ptr;
+				if (!get_vscrollbar_pos(&p->pstart, &p->psize)) {
+					p->pstart = 0;
+					p->psize = 100;
 				}
+				clearmsg(msg);
+				return;
+			}
 			}
 			break;
 		case msg_log_changed: {
@@ -1299,7 +1303,7 @@ void ht_logviewer::handlemsg(htmsg *msg)
 		}
 		case msg_keypressed:
 			switch (msg->data1.integer) {
-				case K_Up:
+			case K_Up:
 				cursor_up(1);
 				update();
 				clearmsg(msg);
@@ -1388,13 +1392,13 @@ static bool doFileChecks(File *file)
 			case HT_S_IFREG: return true;
 			default:
 				LOG_EX(LOG_WARN, "file is not regular (but device, fifo or something...).");
-				LOG_EX(LOG_WARN, "Write-access disabled for safety !");
+				LOG_EX(LOG_WARN, "Write-access disabled for safety!");
 				return true;
 		}
 	} else {
-		LOG_EX(LOG_WARN, "can't determine file type (regular, device, directory...) ! assuming non-regular...");
+		LOG_EX(LOG_WARN, "can't determine file type (regular, device, directory...)! assuming non-regular...");
 		LOG_EX(LOG_WARN, "file is not regular (but device, fifo or something...).");
-		LOG_EX(LOG_WARN, "Write-access disabled for safety !");
+		LOG_EX(LOG_WARN, "Write-access disabled for safety!");
 		return true;
 	}
 	return false;
@@ -1455,7 +1459,7 @@ void ht_app::init(Bounds *pq)
 	file->insert_entry("Open/Create ~project...", NULL, cmd_project_open, 0, 1);
 	file->insert_entry("Close p~roject", NULL, cmd_project_close, 0, 1);
 	file->insert_separator();
-	file->insert_entry("~Execute", "Alt+Z", cmd_file_exec_cmd, K_Meta_Z, 1);
+//	file->insert_entry("~Execute", "Alt+Z", cmd_file_exec_cmd, K_Meta_Z, 1);
 	file->insert_entry("~Quit", "F10", cmd_quit, 0, 1);
 	m->insert_menu(file);
 
@@ -1575,7 +1579,7 @@ bool ht_app::accept_close_all_windows()
 
 ht_window *ht_app::create_window_log()
 {
-	ht_window *w=get_window_by_type(AWT_LOG);
+	ht_window *w = get_window_by_type(AWT_LOG);
 	if (w) {
 		focus(w);
 	} else {
@@ -1715,8 +1719,8 @@ ht_window *ht_app::create_window_clipboard()
 		v->init(&b, "clipboard", VC_EDIT | VC_GOTO | VC_SEARCH, clipboard, 0);
 
 		window->insert(v);
-// FIXME: needs wrapper (layer)
-//		insert_window(window, AWT_CLIPBOARD, 0, false, clipboard);
+		// FIXME: needs wrapper (layer)
+		//insert_window(window, AWT_CLIPBOARD, 0, false, clipboard);
 		insert_window(window, AWT_CLIPBOARD, 0, false, NULL);
 	}
 	return NULL;
@@ -2471,6 +2475,7 @@ void ht_app::handlemsg(htmsg *msg)
 						return;
 					}
 					break;
+/*					
 				case K_Meta_R: {
 					const char *n = "ht.reg";
 					LocalFile f(n, IOAM_WRITE, FOM_CREATE);
@@ -2485,6 +2490,7 @@ void ht_app::handlemsg(htmsg *msg)
 					clearmsg(msg);
 					return;
 				}
+*/
 #if 0
 				/* FIXME: experimental */
 				case K_Control_F9:
@@ -2562,12 +2568,12 @@ void ht_app::handlemsg(htmsg *msg)
 			File *f = (File *)msg->data1.ptr;
 			FileOfs s = msg->data2.q;
 /*			ht_app_window_entry *e;
-			if ((e=windows->enum_first())) {
+			if ((e = windows->enum_first())) {
 				do {
-					if ((e->type==AWT_FILE) && ((File*)e->data==f)) {
+					if (e->type == AWT_FILE && (File*)e->data == f) {
 						check_collide();
 					}
-				} while ((e=windows->enum_first()));
+				} while ((e = windows->enum_next()));
 			}*/
 			String fn;
 			if (confirmbox("really truncate %y at offset 0x%08qx/%qd?", &f->getFilename(fn), s, s) == button_ok) {
@@ -2891,7 +2897,7 @@ int ht_app::popup_view_list_dump(ht_view *view, ht_text_listbox *listbox, List *
 		}
 		if (!v) return count;
 
-// FIXME: "viewergroup": dirty hack !!!
+		// FIXME: "viewergroup": dirty hack !!!
 		if (v->desc && (strcmp(v->desc, VIEWERGROUP_NAME)) && (v->options & VO_BROWSABLE)) {
 			ht_snprintf(s, sizeof str-(s-str), "- %s", v->desc);
 			structure->insert(v);
