@@ -34,8 +34,8 @@ extern format_viewer_if htpefimage_if;
 class ht_pef_aviewer: public ht_aviewer {
 public:
 	ht_pef_shared_data *pef_shared;
-		   void init(bounds *b, char *desc, int caps, ht_streamfile *file, ht_format_group *format_group, Analyser *Analyser, ht_pef_shared_data *pef_shared);
-	virtual int  func_handler(eval_scalar *result, char *name, eval_scalarlist *params);
+		   void init(Bounds *b, const char *desc, int caps, File *file, ht_format_group *format_group, Analyser *Analyser, ht_pef_shared_data *pef_shared);
+	virtual bool func_handler(eval_scalar *result, char *name, eval_scalarlist *params);
 	virtual void setAnalyser(Analyser *a);
 };
 
